@@ -124,9 +124,9 @@ class AppScanParser:
                 else item.find("variant-group/item/test-http-traffic").text
             response = "" if item.find("variant-group/item/issue-information/testResponseChunk") is None \
                 else item.find("variant-group/item/issue-information/testResponseChunk").text
-            cvss = None if item.find("cvss-score") is None else f"CVSS: {item.find('cvss-score').text}"
-            cvss_base_vector = None if item.find('cvss-vector/base-vector') is None \
-                else f"CVSS-base-vector: {item.find('cvss-vector/base-vector').text}"
+            cvss2 = item.find('cvss-score').text if item.find("cvss-score") is not None else None
+            cvss2_base_vector = item.find('cvss-vector/base-vector').text if item.find('cvss-vector/base-vector') \
+                                                                             is not None else None
             cvss_temporal_vector = None if item.find('cvss-vector/temporal-vector') is None \
                 else f"CVSS-temporal-vector: {item.find('cvss-vector/temporal-vector').text}"
             cvss_environmental_vector = None if item.find('cvss-vector/environmental-vector') is None \
@@ -158,18 +158,19 @@ class AppScanParser:
                 "response": response,
                 "website": entity['website'],
                 "path": entity['path'],
-                "cve": []
+                "cve": [],
+                "cwe": [],
+                "cvss2": {}
             }
             if cve:
                 issue_data["cve"].append(cve)
+                issue_data["desc"] += cve
             if cve_url:
                 issue_data["ref"].append(cve_url)
             if cwe:
-                issue_data["ref"].append(f"CWE: {cwe}")
-            if cvss:
-                issue_data["ref"].append(cvss)
-            if cvss_base_vector:
-                issue_data["ref"].append(cvss_base_vector)
+                issue_data["cwe"].append(f"CWE-{cwe}")
+            if cvss2_base_vector:
+                issue_data["cvss2"]["vector_string"] = cvss2_base_vector
             if cvss_temporal_vector:
                 issue_data["ref"].append(cvss_temporal_vector)
             if cvss_environmental_vector:
@@ -190,9 +191,9 @@ class AppScanParser:
             if fix_id:
                 fix = self.fixes[fix_id]
                 resolution = f"{resolution}\nLibrary: {fix['library']}\nLocation: {fix['location']}"
-            cvss = None if item.find("cvss-score") is None else f"CVSS: {item.find('cvss-score').text}"
-            cvss_base_vector = None if item.find('cvss-vector/base-vector') is None \
-                else f"CVSS-base-vector: {item.find('cvss-vector/base-vector').text}"
+            cvss2 = item.find('cvss-score').text if item.find("cvss-score") else None
+            cvss2_base_vector = None if item.find('cvss-vector/base-vector') is None \
+                else item.find('cvss-vector/base-vector').text
             cvss_temporal_vector = None if item.find('cvss-vector/temporal-vector') is None \
                 else f"CVSS-temporal-vector: {item.find('cvss-vector/temporal-vector').text}"
             cvss_environmental_vector = None if item.find('cvss-vector/environmental-vector') is None \
@@ -214,23 +215,24 @@ class AppScanParser:
                 "desc": description,
                 "ref": [],
                 "resolution": resolution,
-                "cve": []
+                "cve": [],
+                "cwe": [],
+                "cvss2": {}
             }
 
-            if cve:
-                issue_data["cve"].append(cve)
             if cve_url:
                 issue_data["ref"].append(cve_url)
             if cwe:
-                issue_data["ref"].append(f"CWE: {cwe}")
-            if cvss:
-                issue_data["ref"].append(cvss)
-            if cvss_base_vector:
-                issue_data["ref"].append(cvss_base_vector)
+                issue_data["cwe"].append(f"CWE-{cwe}")
+            if cvss2_base_vector:
+                issue_data["cvss2"]['vector_string'] = cvss2_base_vector
             if cvss_temporal_vector:
                 issue_data["ref"].append(cvss_temporal_vector)
             if cvss_environmental_vector:
                 issue_data["ref"].append(cvss_environmental_vector)
+            if cve:
+                issue_data["cve"].append(cve)
+                issue_data["desc"] += f"\nCVE: {cve}"
             # Build data
             data = []
             if item.attrib.get("caller"):
@@ -239,15 +241,8 @@ class AppScanParser:
                 data.append(f"Method: {item.find('variant-group/item/issue-information/method-signature').text}")
             if item.find("variant-group/item/issue-information/method-signature2") is not None:
                 data.append(f"Location: {item.find('variant-group/item/issue-information/method-signature2').text}")
-            line = item.find("location")
-            highlight = item.find("variant-group/item/issue-information/call-trace/call-invocation/context/highlight")
-            if highlight is not None:
-                data.append(f" {highlight.text}")
-                issue_data["desc"] += "\n" + highlight.text
-            if line is not None and len(line.text.split(':')) > 1 and line.text.split(':')[-1].isdigit():
-                data.append(f"line {line.text.split(':')[-1]}")
-                issue_data["desc"] += f"line {line.text.split(':')[-1]}"
             issue_data['data'] = "\n".join(data)
+            issue_data['desc'] += "\n".join(data)
             sast_issues.append(issue_data)
         return sast_issues
 
@@ -285,5 +280,5 @@ class AppScanPlugin(PluginXMLFormat):
                 self.createAndAddVulnToHost(host_id=host_id, **issue)
 
 
-def createPlugin(ignore_info=False, hostname_resolution=True):
-    return AppScanPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
+def createPlugin(*args, **kwargs):
+    return AppScanPlugin(*args, **kwargs)
