@@ -287,5 +287,5 @@ class SslyzePlugin(PluginJsonFormat):
                           command_string)
 
 
-def createPlugin(ignore_info=False, hostname_resolution=True):
-    return SslyzePlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
+def createPlugin(*args, **kwargs):
+    return SslyzePlugin(*args, **kwargs)
