@@ -150,5 +150,5 @@ class WebInspectPlugin(PluginXMLFormat):
             )
 
 
-def createPlugin(ignore_info=False, hostname_resolution=True):
-    return WebInspectPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
+def createPlugin(*args, **kwargs):
+    return WebInspectPlugin(*args, **kwargs)
